@@ -1,13 +1,10 @@
 import logging
 
-from collections import OrderedDict
-
-from django.conf import settings
 from django.db import transaction, DEFAULT_DB_ALIAS
 from django.db.transaction import get_connection
 from django.db.transaction import TransactionManagementError
 
-from contextlib import contextmanager, ContextDecorator
+from contextlib import contextmanager
 
 
 logger = logging.getLogger(__name__)
@@ -30,7 +27,7 @@ def pre_commit(func, using=None):
         func()
 
 
-def smart_atomic(using=None, savepoint=True, ignore_errors=None, reversion=True):
+def smart_atomic(using=None, savepoint=True, ignore_errors=None, reversion=True, reversion_using=None):
     """
     Decorator and context manager that overrides django atomic decorator and automatically adds create revision.
     The _atomic closure is required to achieve save ContextDecorator that nest more inner context decorator.
@@ -40,19 +37,19 @@ def smart_atomic(using=None, savepoint=True, ignore_errors=None, reversion=True)
     ignore_errors = () if ignore_errors is None else ignore_errors
 
     @contextmanager
-    def _atomic(using=None, savepoint=True, reversion=True):
+    def _atomic(using=None, savepoint=True, reversion=True, reversion_using=None):
         try:
             from reversion.revisions import create_revision
         except ImportError:
             reversion = False
 
         if not reversion:
-            @contextmanager
-            def create_revision(*args, **kwargs):
+            @contextmanager  # noqa: F811
+            def create_revision(*args, **kwargs):  # noqa: F811
                 yield
 
         error = None
-        with transaction.atomic(using, savepoint), create_revision(using=using):
+        with transaction.atomic(using, savepoint), create_revision(using=reversion_using):
             try:
                 yield
             except ignore_errors as ex:
@@ -62,9 +59,9 @@ def smart_atomic(using=None, savepoint=True, ignore_errors=None, reversion=True)
             raise error  # pylint: disable=E0702
 
     if callable(using):
-        return _atomic(DEFAULT_DB_ALIAS, savepoint, reversion)(using)
+        return _atomic(DEFAULT_DB_ALIAS, savepoint, reversion, reversion_using)(using)
     else:
-        return _atomic(using, savepoint, reversion)
+        return _atomic(using, savepoint, reversion, reversion_using)
 
 
 def in_atomic_block(using=None):
